# Darcy flow with heat advection and conduction
[Mesh]
  file = 2019_06_06_full_TH2.e
[]
#############################################################
[GlobalParams]
  PorousFlowDictator = dictator
[]
############################################################
[Variables]
  [./pressure]
  initial_from_file_var = pressure
  initial_from_file_timestep = 1
  # initial_condition = 1e7
  [../]
  [./temperature]
  initial_from_file_var = temperature
  initial_from_file_timestep = 1
  #initial_condition = 327
  #scaling = 1E-8
  [../]
[]
###########################################################
[AuxVariables]
    [./vel_x]
    order = CONSTANT
    family = MONOMIAL
  [../]
  [./vel_y]
    order = CONSTANT
    family = MONOMIAL
  [../]
  [./vel_z]
    order = CONSTANT
    family = MONOMIAL
  [../]
  [./fluid_density]
    order = CONSTANT
    family = MONOMIAL
  [../]
  [./viscosity]
    order = CONSTANT
    family = MONOMIAL
  [../]
[]
###########################################################

############################################################
[Kernels]
#  [./P_time_deriv]
#    type = PorousFlowMassTimeDerivative
#    fluid_component = 0
#    variable = P
#  [../]
  [./P_flux]
    type = PorousFlowAdvectiveFlux
    fluid_component = 0
    variable = pressure
    gravity = '0 0 -9.8'
  [../]
#  [./energy_dot]
#    type = PorousFlowEnergyTimeDerivative
#    variable = T
# [../]
  [./heat_conduction]
    type = PorousFlowHeatConduction
    variable = temperature
  [../]
#  [./heat_advection]
#    type = PorousFlowHeatAdvection
#    variable = T
#    gravity = '0 0 -9.8'
#  [../]
[]
##############################################################
[AuxKernels]
  [./vel_x]
    type = PorousFlowDarcyVelocityComponent
    variable = vel_x
    component = x
    fluid_phase = 0
    gravity = '0 0 -9.8'
  [../]
  [./vel_y]
    type = PorousFlowDarcyVelocityComponent
    variable = vel_y
    component = y
    fluid_phase = 0
    gravity = '0 0 -9.8'
  [../]
  [./vel_z]
    type = PorousFlowDarcyVelocityComponent
    variable = vel_z
    component = z
    fluid_phase = 0
    gravity = '0 0 -9.8'
  [../]
  [./fluid_density]
    type = MaterialRealAux
     variable = fluid_density
     property = density
  [../]
  [./viscosity]
    type = MaterialRealAux
     variable = viscosity
     property = viscosity
  [../]
[]


###########
[AuxVariables]
#this reads the values from the exodus mesh
  [./porosity]
	family = monomial
	order = constant
	initial_from_file_var = porosity
  [../]

  [./perm_x]
	family = monomial
	order = constant
	initial_from_file_var = kii
  [../]

  [./perm_y]
	family = monomial
	order = constant
	initial_from_file_var = kjj
  [../]

  [./perm_z]
	family = monomial
	order = constant
	initial_from_file_var = kkk
  [../]

[]

###############################################################
[UserObjects]
  [./solution_uo]
#this reads the solution values from an exodus mesh
    type = SolutionUserObject
    mesh = '2019_06_06_full_TH2.e'
    timestep = 'LATEST'
    execute_on = 'INITIAL'
  [../]

  [./dictator]
    type = PorousFlowDictator
    porous_flow_vars = 'pressure temperature'
    number_fluid_phases = 1
    number_fluid_components = 1
  [../]

  [./pc]
    type = PorousFlowCapillaryPressureVG
    alpha = 1E-8
    m = 0.5
  [../]
[]
##########################
[Functions]
  [./pressure_BC]
    type = SolutionFunction
    from_variable = pressure
    solution = solution_uo
  [../]

  [./temperature_BC]
    type = SolutionFunction
    from_variable = temperature
    solution = solution_uo
  [../]
[]

###############################################################
[BCs]
  [./P_top]
    type = FunctionDirichletBC
    variable = pressure
    boundary = top
    function = pressure_BC
  [../]

  [./T_top]
    type = FunctionDirichletBC
    variable = temperature
    boundary = top
    function = temperature_BC
  [../]

  [./T_bot]
    type = FunctionDirichletBC
    variable = temperature
    boundary = bottom
    function = temperature_BC
  [../]

  [./T_left]
    type = FunctionDirichletBC
    variable = temperature
    boundary = left
    function = temperature_BC
  [../]

  [./T_right]
    type = FunctionDirichletBC
    variable = temperature
    boundary = right
    function = temperature_BC
  [../]

  [./T_front]
    type = FunctionDirichletBC
    variable = temperature
    boundary = front
    function = temperature_BC
  [../]

  [./T_back]
    type = FunctionDirichletBC
    variable = temperature
    boundary = back
    function = temperature_BC
  [../]

 # [./T_inj]
 #   type = FunctionPresetBC
 #   variable = T
 #   boundary = '22'
 #   function = '523'
 # [../]
[]
############################################################

############################################################
[Modules]
  [./FluidProperties]
    [./water]
      type = Water97FluidProperties
    [../]
  [../]
[]
############################################################



############################################################
[Materials]
  [./temperature]
    type = PorousFlowTemperature
    temperature = temperature
  [../]

  [./temperature_nodal]
    type = PorousFlowTemperature
    at_nodes = true
    temperature = temperature
  [../]

  [./ppss]
    type = PorousFlow1PhaseP
    at_nodes = true
    porepressure = pressure
    capillary_pressure = pc
  [../]

  [./ppss_qp]
    type = PorousFlow1PhaseP
    porepressure = pressure
    capillary_pressure = pc
  [../]

  [./massfrac]
    type = PorousFlowMassFraction
    at_nodes = true
  [../]

  [./fluid_props]
    type = PorousFlowSingleComponentFluid
    fp = water
    phase = 0
    at_nodes = true
  [../]

  [./fluid_props_qp]
    type = PorousFlowSingleComponentFluid
    phase = 0
    fp = water
  [../]

  [./relperm]
    type = PorousFlowRelativePermeabilityCorey
    at_nodes = true
    n = 1
    phase = 0
  [../]

  [./relperm_qp]
    type = PorousFlowRelativePermeabilityCorey
    n = 1
    phase = 0
  [../]

  [./fp_mat]
    type = FluidPropertiesMaterialPT
    pressure = pressure
    temperature = temperature
    fp = water
  [../]

 [./rock_heat_sediments]
    type = PorousFlowMatrixInternalEnergy
    specific_heat_capacity = 830.0
    density = 2400
    block = 1
#density from Rick allis analysis, specific heat per tabulated values
  [../]

  [./rock_heat_granitoid]
    type = PorousFlowMatrixInternalEnergy
    specific_heat_capacity = 790.0
    density = 2640
    block = 2
#density from Rick allis analysis, specific heat per tabulated values
  [../]

  [./thermal_conductivity_sediments]
    type = PorousFlowThermalConductivityIdeal
    dry_thermal_conductivity = '2 0 0  0 2 0  0 0 2'
    block = 1
  [../]

  [./thermal_conductivity_granitoid]
    type = PorousFlowThermalConductivityIdeal
    dry_thermal_conductivity = '3.05 0 0  0 3.05 0  0 0 3.05'
    block = 2
  [../]

####################################################
#reading from MESH file
 [./permeability]
    type = PorousFlowPermeabilityConstFromVar
    perm_xx = perm_x
    perm_yy = perm_y
    perm_zz = perm_z
  [../]

#porosity is picked up as an AuxVariable


[]
############################################################
[Preconditioning]
  active = 'preferred'
  [./original]
    type = SMP
    full = true
    petsc_options = '-ksp_diagonal_scale -ksp_diagonal_scale_fix'
    petsc_options_iname = '-ksp_type -pc_type -sub_pc_type -sub_pc_factor_shift_type'
    petsc_options_value = 'gmres asm lu NONZERO'
  [../]
  [./superlu]
    type = SMP
    full = true
    petsc_options = '-ksp_diagonal_scale -ksp_diagonal_scale_fix'
    petsc_options_iname = '-ksp_type -pc_type -pc_factor_mat_solver_package'
    petsc_options_value = 'gmres lu superlu_dist'
  [../]
  [./sub_pc_superlu]
    type = SMP
    full = true
    petsc_options = '-ksp_diagonal_scale -ksp_diagonal_scale_fix'
    petsc_options_iname = '-ksp_type -pc_type -sub_pc_type -sub_pc_factor_shift_type -sub_pc_factor_mat_solver_package'
    petsc_options_value = 'gmres asm lu NONZERO superlu_dist'
  [../]
  [./preferred]
#per Andy
    type = SMP
    full = true
    petsc_options_iname = '-pc_type -pc_factor_mat_solver_package'
    petsc_options_value = ' lu       mumps'
  [../]
[]
############################################################
[Postprocessors]
 # [./dt]
 #   type = TimestepSize
 # [../]

 # [./P_58_32]
 #   type = PointValue
 #   execute_on = 'initial timestep_end'
 #   point = '335329 4263052 -612'
 #   variable = P
 # [../]


 # [./T_58_32]
 #   type = PointValue
 #  execute_on = 'initial timestep_end'
 #   point =  '335329 4263052 -612'
 #   variable = T
 # [../]


 # [./1_T_250.0.0]
 #   type = PointValue
 #   execute_on = 'initial timestep_end'
 #   point = '250 0 0'
 #   variable = T
 # [../]

#  [./1_Mass_Inj]
#    type = PorousFlowPlotQuantity
#    uo = dummy_inj_P
#    execute_on = 'initial timestep_end'
#  [../]
#  [./2_Mass_Prod]
#    type = PorousFlowPlotQuantity
#    uo = dummy_prod_P
#    execute_on = 'initial timestep_end'
#  [../]
#  [./3_Energy_Prod]
#    type = PorousFlowPlotQuantity
#    uo = dummy_prod_T
#    execute_on = 'initial timestep_end'
#  [../]
[]


[VectorPostprocessors]

#  [./reader]
#    type = CSVReader
#    csv_file = rotated_58_32_coordinates.csv
#  [../]

  [./point_sample]
    type = PointValueSampler
    variable = 'temperature pressure'
    points = '1745.06    1041.96    1224.46
1744.68    1042.38    1193.99
1744.24    1042.81    1163.52
1743.73    1043.24    1133.05
1743.28    1043.78    1102.58
1742.99    1044.48    1072.11
1742.85    1045.34    1041.64
1742.87    1046.29    1011.18
1743.1    1047.01    980.71
1743.54    1047.47    950.24
1744    1047.8    919.76
1744.28    1048.14    889.29
1744.38    1048.49    858.81
1744.31    1048.84    828.34
1744.07    1049.16    797.86
1743.68    1049.41    767.38
1743.13    1049.61    736.91
1742.79    1049.74    706.44
1742.87    1049.76    675.96
1743.36    1049.7    645.48
1743.8    1049.43    615.01
1743.97    1048.92    584.54
1743.86    1048.16    554.07
1743.39    1047.2    523.61
1742.45    1046.08    493.16
1741.05    1044.79    462.75
1739.27    1043.28    432.36
1737.16    1041.52    402
1734.72    1039.51    371.69
1732.1    1037.34    341.4
1729.44    1035.08    311.12
1726.59    1032.84    280.86
1723.06    1031.5    250.62
1719.65    1030.08    220.36
1716.28    1028.85    190.1
1713.91    1027.96    159.73
1712.92    1027.19    129.28
1712.07    1026.96    98.81
1711.51    1026.75    68.34
1711.13    1026.15    37.87
1711.19    1025.86    7.39
1711.38    1025.63    -23.08
1711.67    1025.47    -53.56
1711.62    1025.49    -84.04
1711.02    1025.73    -114.51
1710.34    1026.21    -144.98
1709.73    1026.92    -175.44
1709.09    1027.77    -205.9
1708.41    1028.71    -236.36
1707.65    1029.72    -266.81
1706.69    1030.6    -297.26
1705.47    1030.87    -327.71
1703.91    1030.49    -358.15
1701.97    1029.85    -388.56
1700.31    1029.39    -418.98
1699.67    1029.04    -449.45
1699.09    1028.91    -479.93
1698.47    1028.68    -510.4
1697.72    1028.4    -540.86
1696.85    1028.06    -571.33
1695.96    1027.72    -601.79'
    sort_by = z
  [../]
[]
############################################################
[Executioner]
#  type = Transient
  type = Steady

  solve_type = Newton
#  end_time = 1E6
#  dt = 1E5
#   nl_abs_tol = 1E-08

nl_rel_tol = 1e-8

[]
############################################################
[Outputs]

  execute_on = 'timestep_end'
  exodus  = true

  [./console]
    type = Console
    output_linear = true
    output_nonlinear = true
    verbose = true
  [../]

  [pgraph]
    type = PerfGraphOutput
    execute_on = 'final'  # Default is "final"
    level = 2                     # Default is 1
    heaviest_branch = true        # Default is false
    heaviest_sections = 5         # Default is 0
 [../]


[./CSV]
    type = CSV
  [../]
[]
############################################################
