# Darcy flow with heat advection and conduction
[Mesh]
  file = 2019_06_10_full_THM.e
[]
#############################################################
[GlobalParams]
  displacements = 'disp_i disp_j disp_k'
[]
############################################################
[Variables]

 [./disp_i]
    scaling = 1E-10
  [../]
  [./disp_j]
    scaling = 1E-10
  [../]
  [./disp_k]
    scaling = 1E-10
  [../]
[]
###############################################################
[AuxVariables]

  [./pressure]
    initial_from_file_var = pressure
    initial_from_file_timestep = 1
  [../]

  [./temperature]
    initial_from_file_var = temperature
    initial_from_file_timestep = 1
  [../]

  [./depth]
    initial_from_file_var = depth
    initial_from_file_timestep = 1
  [../]

  [./stress_ii]
    order = CONSTANT
    family = MONOMIAL
  [../]

  [./stress_ij]
    order = CONSTANT
    family = MONOMIAL
  [../]

  [./stress_ik]
    order = CONSTANT
    family = MONOMIAL
  [../]

  [./stress_jj]
    order = CONSTANT
    family = MONOMIAL
  [../]

  [./stress_jk]
    order = CONSTANT
    family = MONOMIAL
  [../]

  [./stress_kk]
    order = CONSTANT
    family = MONOMIAL
  [../]
[]
###########################################################
[Kernels]

[./TensorMechanics]
    displacements = 'disp_i disp_j disp_k'
[../]

[./poro_i]
    type = PoroMechanicsCoupling
    variable = disp_i
    porepressure = pressure
    component = 0
[../]

[./poro_j]
    type = PoroMechanicsCoupling
    variable = disp_j
    porepressure = pressure
    component = 1
[../]

[./poro_k]
    type = PoroMechanicsCoupling
    variable = disp_k
    porepressure = pressure
    component = 2
[../]

[./weight]
    type = Gravity
    variable = disp_k
    value = -9.8
[../]

[]
###########################################################
[AuxKernels]

[./stress_ii]
    type = RankTwoAux
    rank_two_tensor = stress
    variable = stress_ii
    index_i = 0
    index_j = 0
[../]

[./stress_ij]
    type = RankTwoAux
    rank_two_tensor = stress
    variable = stress_ij
    index_i = 0
    index_j = 1
[../]

[./stress_ik]
    type = RankTwoAux
    rank_two_tensor = stress
    variable = stress_ik
    index_i = 0
    index_j = 2
[../]

[./stress_jj]
    type = RankTwoAux
    rank_two_tensor = stress
    variable = stress_jj
    index_i = 1
    index_j = 1
[../]

[./stress_jk]
    type = RankTwoAux
    rank_two_tensor = stress
    variable = stress_jk
    index_i = 1
    index_j = 2
[../]

[./stress_kk]
    type = RankTwoAux
    rank_two_tensor = stress
    variable = stress_kk
    index_i = 2
    index_j = 2
[../]

[]

###########################################################
[UserObjects]

#this reads the solution values from an exodus mesh
[./solution_uo]
    type = SolutionUserObject
    mesh = '2019_06_10_full_THM.e'
    timestep = 'LATEST'
    execute_on = 'INITIAL'
[../]
[]

##########################
[Functions]
#these are for ICs
  [./vertical]
    type = SolutionFunction
    from_variable = vertical
    solution = solution_uo
#type = ParsedFunction
#value = '(-0.0256*1000000 * depth) + (0.00979*1000000 * depth)'
  [../]

  [./h_min]
    type = SolutionFunction
    from_variable = h_min
    solution = solution_uo
#  type = ParsedFunction
#   value = '(-0.0140*1000000 * depth)+(0.00979*1000000 *depth)'
  [../]

  [./h_max]
    type = SolutionFunction
    from_variable = h_max
    solution = solution_uo
#    type = ParsedFunction
#   value = '(-0.0174*1000000 * depth)+(0.00979*1000000 * depth)'
  [../]

#these are for BCs
[./overburden_vertical_stress_BC]
    type = SolutionFunction
    from_variable = disp_k_bc
    solution = solution_uo
[../]

[./pressure_sigma_h_max]
    type = SolutionFunction
    from_variable = disp_j_bc
    solution = solution_uo
[../]

[./pressure_sigma_h_min]
    type = SolutionFunction
    from_variable = disp_i_bc
    solution = solution_uo
[../]
[]

##########################
[BCs]

[./roller_sigma_h_min]
    type = PresetBC
    variable = disp_i
    value = 0
    boundary = 'left'
[../]

[./roller_sigma_h_max]
    type = PresetBC
    variable = disp_j
    value = 0
    boundary = 'front'
[../]

[./roller_signma_v]
    type = PresetBC
    variable = disp_k
    value = 0
    boundary = 'bottom'
[../]

# need an overburden_stress
[./overburden_vertical_stress]
    type = FunctionNeumannBC
    variable = disp_k
    boundary = 'top'
    function = overburden_vertical_stress_BC
[../]

[./pressure_sigma_h_max]
    type = FunctionNeumannBC
    variable = disp_j
    boundary = 'back'
    function = pressure_sigma_h_max
[../]

[./pressure_sigma_h_min]
    type = FunctionNeumannBC
    variable = disp_i
    boundary = 'right'
    function = pressure_sigma_h_min
[../]
[]

##########################
[Materials]
  [./density_sediments]
    type = GenericConstantMaterial
    block = 1
    prop_names = density
    prop_values = 2500
  [../]

  [./density_granite]
    type = GenericConstantMaterial
    block = 2
    prop_names = density
    prop_values = 2750
  [../]

  [./elasticity_tensor_granite]
    type = ComputeIsotropicElasticityTensor
    youngs_modulus = 6.2E10
    poissons_ratio = 0.3
    block = 2
  [../]

  [./elasticity_tensor_sediment]
    type = ComputeIsotropicElasticityTensor
    youngs_modulus = 3.0E10
    poissons_ratio = 0.3
    block = 1
  [../]

  [./biot]
    type = GenericConstantMaterial
    prop_names = biot_coefficient
    prop_values = 0.6
  [../]

  [./strain]
    type = ComputeSmallStrain
    eigenstrain_names = 'thermal_contribution ini_stress'
  [../]

  [./thermal_contribution]
    type = ComputeThermalExpansionEigenstrain
    temperature = temperature
    thermal_expansion_coeff = 2.0e-6  # this is the linear thermal expansion coefficient
    eigenstrain_name = thermal_contribution
    stress_free_temperature = temperature  #not sure what to do with this?
  [../]

#what to do here??
  [./strain_from_initial_stress]
    type = ComputeEigenstrainFromInitialStress
    initial_stress = 'h_min 0 0  0 h_max 0  0 0 vertical'
    eigenstrain_name = ini_stress
  [../]

  [./stress]
    type = ComputeLinearElasticStress
  [../]
[]
############################################################
[Preconditioning]
  active = 'superlu'
  [./original]
    type = SMP
    full = true
    petsc_options = '-ksp_diagonal_scale -ksp_diagonal_scale_fix'
    petsc_options_iname = '-ksp_type -pc_type -sub_pc_type -sub_pc_factor_shift_type'
    petsc_options_value = 'gmres asm lu NONZERO'
  [../]

  [./superlu]
    type = SMP
    full = true
    petsc_options = '-ksp_diagonal_scale -ksp_diagonal_scale_fix'
    petsc_options_iname = '-ksp_type -pc_type -pc_factor_mat_solver_package'
    petsc_options_value = 'gmres lu superlu_dist'
  [../]

  [./sub_pc_superlu]
    type = SMP
    full = true
    petsc_options = '-ksp_diagonal_scale -ksp_diagonal_scale_fix'
    petsc_options_iname = '-ksp_type -pc_type -sub_pc_type -sub_pc_factor_shift_type -sub_pc_factor_mat_solver_package'
    petsc_options_value = 'gmres asm lu NONZERO superlu_dist'
  [../]

  [./preferred]
#per Andy
    type = SMP
    full = true
    petsc_options_iname = '-pc_type -pc_factor_mat_solver_package'
    petsc_options_value = ' lu       mumps'
  [../]

  [./basic]
    type = SMP
    full = true
    petsc_options = '-ksp_diagonal_scale -ksp_diagonal_scale_fix'
    petsc_options_iname = '-pc_type -sub_pc_type -sub_pc_factor_shift_type -pc_asm_overlap'
    petsc_options_value = ' asm      lu           NONZERO                   2'
  [../]
[]
############################################################
[VectorPostprocessors]

  [./point_sample]
    type = PointValueSampler
    variable = 'stress_ii stress_jj stress_kk'
    points = '1745.06    1041.96    1224.46
1744.68    1042.38    1193.99
1744.24    1042.81    1163.52
1743.73    1043.24    1133.05
1743.28    1043.78    1102.58
1742.99    1044.48    1072.11
1742.85    1045.34    1041.64
1742.87    1046.29    1011.18
1743.1    1047.01    980.71
1743.54    1047.47    950.24
1744    1047.8    919.76
1744.28    1048.14    889.29
1744.38    1048.49    858.81
1744.31    1048.84    828.34
1744.07    1049.16    797.86
1743.68    1049.41    767.38
1743.13    1049.61    736.91
1742.79    1049.74    706.44
1742.87    1049.76    675.96
1743.36    1049.7    645.48
1743.8    1049.43    615.01
1743.97    1048.92    584.54
1743.86    1048.16    554.07
1743.39    1047.2    523.61
1742.45    1046.08    493.16
1741.05    1044.79    462.75
1739.27    1043.28    432.36
1737.16    1041.52    402
1734.72    1039.51    371.69
1732.1    1037.34    341.4
1729.44    1035.08    311.12
1726.59    1032.84    280.86
1723.06    1031.5    250.62
1719.65    1030.08    220.36
1716.28    1028.85    190.1
1713.91    1027.96    159.73
1712.92    1027.19    129.28
1712.07    1026.96    98.81
1711.51    1026.75    68.34
1711.13    1026.15    37.87
1711.19    1025.86    7.39
1711.38    1025.63    -23.08
1711.67    1025.47    -53.56
1711.62    1025.49    -84.04
1711.02    1025.73    -114.51
1710.34    1026.21    -144.98
1709.73    1026.92    -175.44
1709.09    1027.77    -205.9
1708.41    1028.71    -236.36
1707.65    1029.72    -266.81
1706.69    1030.6    -297.26
1705.47    1030.87    -327.71
1703.91    1030.49    -358.15
1701.97    1029.85    -388.56
1700.31    1029.39    -418.98
1699.67    1029.04    -449.45
1699.09    1028.91    -479.93
1698.47    1028.68    -510.4
1697.72    1028.4    -540.86
1696.85    1028.06    -571.33
1695.96    1027.72    -601.79'
    sort_by = z
  [../]
[]
############################################################
[Executioner]
#  type = Transient
type = Steady
solve_type = Newton

#   end_time = 1.0
#   dt = 0.1

l_max_its  = 50
l_tol      = 1e-5
nl_max_its = 10

nl_abs_tol = 1E-11
nl_rel_tol = 1e-8
[]
############################################################
[Outputs]
  exodus  = true

  [./console]
    type = Console
    output_linear = true
    output_nonlinear = true
    verbose = true
  [../]

  [pgraph]
    type = PerfGraphOutput
    execute_on = 'final'        # Default is "final"
    level = 2                     # Default is 1
    heaviest_branch = true        # Default is false
    heaviest_sections = 5         # Default is 0
  [../]

  [./CSV]
    type = CSV
  [../]
[]
############################################################
